package jp.co.argo21.nautica.workflow.soap;

import javax.annotation.Resource;
import javax.jws.WebService;
import javax.naming.NamingException;
import javax.xml.ws.WebServiceContext;

import org.apache.log4j.Logger;

import jp.co.argo21.nautica.workflow.omg.WorkflowException;
import jp.co.argo21.nautica.workflow.soap.message.Organization;
import jp.co.argo21.nautica.workflow.soap.message.User;
import jp.co.argo21.nautica.workflow.util.StringManager;
import jp.co.argo21.nautica.workflow.wfmc.WorkflowSecurityException;

@WebService(serviceName = "OrganizationManager",
        portName="OrganizationManagerPort",
        endpointInterface = "jp.co.argo21.nautica.workflow.soap.OrganizationManager",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap",
        wsdlLocation = "WEB-INF/wsdl/OrganizationManager.wsdl")
public class OrganizationManagerSoapBindingImpl implements OrganizationManager {

	/** ログ出力用オブジェクト */
	private static Logger log = Logger.getLogger(
			RoleManagerSoapBindingImpl.class);
	
	@Resource
    private WebServiceContext context;
	
	/**
	 * 組織に属しているユーザの一覧を返す。
	 *
	 * @param org 組織単位
	 * @return ユーザ一覧
	 * @throws WorkflowException 
	 */
	@Override
	public User[] getAssignedUser(Organization org) throws WorkflowException {
		
		String I1003 = StringManager.get("I1003")
			+ "(Organization=" + org + ")";
		log.info(I1003);
		
		jp.co.argo21.nautica.workflow.security.User[] user = null;
		try {
			jp.co.argo21.nautica.workflow.security.OrganizationManager orgManager = SingletonServices.getInstance().getOrganizationManager();
			user = orgManager.getAssignedUser(org.toDataaccessOrganizationBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1019");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1006 = StringManager.get("I1006") 
			+ "(user=" + user + ")";
		log.info(I1006);
		return SoapMessageConverter.convertToSoapMessage(user);
		
	}

	/**
	 * 該当組織の上位組織を返す。
	 *
	 * @param org 組織単位
	 * @return 上位組織
	 * ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@Override
	public Organization getHigherOrganization(Organization org) throws WorkflowException {
		
		String I1003 = StringManager.get("I1003")
			+ "(Organization=" + org + ")";
		log.info(I1003);
		
		jp.co.argo21.nautica.workflow.security.Organization hiorg = null;
		try {
			jp.co.argo21.nautica.workflow.security.OrganizationManager orgManager = SingletonServices.getInstance().getOrganizationManager();
			hiorg = orgManager.getHigherOrganization(org.toDataaccessOrganizationBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1021");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1006 = StringManager.get("I1006") 
			+ "(HigherOrganization=" + hiorg + ")";
		log.info(I1006);
		return new jp.co.argo21.nautica.workflow.soap.message.Organization(hiorg);
		
	}

	/**
	 * oidに対応する組織を返す。
	 *
	 * @param oid 組織ID
	 * @return 組織単位
	 * @throws WorkflowException 
	 */
	@Override
	public Organization getOrganization(String oid) throws WorkflowException {
		
		String I1003 = StringManager.get("I1003")
			+ "(OrganizationInstanceID=" + oid + ")";
		log.info(I1003);
		
		jp.co.argo21.nautica.workflow.security.Organization org = null;
		try {
			jp.co.argo21.nautica.workflow.security.OrganizationManager orgManager = SingletonServices.getInstance().getOrganizationManager();
			org = orgManager.getOrganization(oid);
		} catch (NamingException e) {
			String errMsg = StringManager.get("1018");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1006 = StringManager.get("I1006") 
			+ "(Organization=" + org + ")";
		log.info(I1006);
		return new jp.co.argo21.nautica.workflow.soap.message.Organization(org);
	}

	/**
	 * ユーザの所属する組織を返す。
	 * 
	 * @param user ユーザ
	 * @return 組織一覧
	 * @throws WorkflowException 
	 * @throws WorkflowSecurityException その他のセキュリティ例外
	 */
	@Override
	public Organization[] getOrganizationByUser(User user) throws WorkflowException {
		
		String I1003 = StringManager.get("I1003")
			+ "(User=" + user + ")";
		log.info(I1003);
		
		jp.co.argo21.nautica.workflow.security.Organization[] org = null;
		try {
			jp.co.argo21.nautica.workflow.security.OrganizationManager orgManager = SingletonServices.getInstance().getOrganizationManager();
			org = orgManager.getOrganizationByUser(user.toDataaccessUserBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1020");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1006 = StringManager.get("I1006") 
			+ "(Organization=" + org + ")";
		log.info(I1006);
		return SoapMessageConverter.convertToSoapMessage(org);
		
	}

	public WebServiceContext getContext() {
		return context;
	}
	
}